// -*- C++ -*-

//=============================================================================
/**
 *  @file    Codeset_Translator_Base.cpp
 *
 * factories are responsible for supplying the proper translator on
 * demand.
 *
 *  @author   Phil Mesnier <mesnier_p@ociweb.com>
 */
//=============================================================================


#include "tao/Codeset_Translator_Base.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Codeset_Translator_Base::~TAO_Codeset_Translator_Base ()
{

}

TAO_END_VERSIONED_NAMESPACE_DECL
